# Generated by Django 2.2.3 on 2019-08-08 11:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('rating', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='objectrating',
            options={'ordering': ('id',), 'verbose_name': 'Rating'},
        ),
    ]
